import { Component, OnInit, ViewChild } from '@angular/core';
import { DatatableComponent } from "@swimlane/ngx-datatable";
import { DocumentsService } from '../../_services/index';
import { UserTypeConnectionDetector } from '../../_class/UserTypeConnectionDetector'; 
import { Http, ResponseContentType } from '@angular/http';
import { Router } from '@angular/router';
import { AuthenticationService } from '../../_services/index';
@Component({
  selector: 'app-documents',
  templateUrl: './documents.component.html',
  styleUrls: ['./documents.component.css']
})
export class DocumentsComponent implements OnInit {
  rowsReports = [];
  rowsBills = [];
  rowsOthers = [];
  loadingIndicator: boolean = true;
  reorderable: boolean = true;
  columns = [
    { prop: 'url', name: "Nom de fichier" },
    { prop: 'created_at', name: "Date et heure de création" }
  ];

  rows = [];
  expanded = {};
  timeout: any;

  rowsFilter = [];
  tempFilter = [];
  reportsFilter = [];
  billsFilter = [];
  othersFilter = [];


  rapports: any;
  factures: any;
  autres:any;
  _currentUserInfos: any;
  _idOfUsers = { "cooperative_id": 0, "technician_id": 0, "farmer_id": 0, "user_type": "t" }; //--------------!!!! // use to load a binding datas of a curent user or to filtering data 
  @ViewChild(DatatableComponent) table: DatatableComponent;

  constructor(
     private http: Http,
     private docsService : DocumentsService,
     private userType : UserTypeConnectionDetector,
     private router: Router,
     public authenticationService: AuthenticationService) {
    
    if (this.authenticationService.isLoggedIn()) {
      this.setIdOfUsersUsigLocalSorage();
    } else {
      this.router.navigate(['/login']); //--------------!!!!
    }
  	var _obj = this;

  	var right = userType.getUserRight();
  	//SWITCH POUR GERER LE CAS DES RECHERCHE DE DOCUMENTS PAR COOPERATIVE (id)
  	switch(right) {
  		case "c":
        console.log('connecté en tant que coop avec l\'id : '+ userType.getIdUser());

  			//Generation du tableau affichant les rapports
		  	this.rapports = docsService.getRapportsByIdUser({user_id : userType.getIdUser()}).then((data) =>  {
		      let dataJson = JSON.parse(data._body);
          dataJson = _obj.transformUrlToFileName(dataJson);
          this.transformDate(dataJson);
		      _obj.rowsReports = dataJson;
          _obj.reportsFilter = [...dataJson];
		    }
		    ,(error)=>{
		      console.error(error);
		      // this.addNotify({title:'Echec du téléchargement', type:'error'});
		    });

		  	//Generation du tableau affichant les factures
		    this.factures = docsService.getFacturesByIdUser({user_id : userType.getIdUser()}).then((data) =>  {
		      let dataJson = JSON.parse(data._body);
		      dataJson = _obj.transformUrlToFileName(dataJson);
          this.transformDate(dataJson);
		      _obj.rowsBills = dataJson;
          _obj.billsFilter = [...dataJson];
		    }
		    ,(error)=>{
		      console.error(error);
		      // this.addNotify({title:'Echec du téléchargement', type:'error'});
		    });

        //Generation du tableau affichant les autres documents (divers)
        this.autres = docsService.getAutresByIdUser({user_id : userType.getIdUser()}).then((data) =>  {
          let dataJson = JSON.parse(data._body);
          dataJson = _obj.transformUrlToFileName(dataJson);
          this.transformDate(dataJson);
          _obj.rowsOthers = dataJson;
          _obj.othersFilter = [...dataJson];
        }
        ,(error)=>{
          console.error(error);
          // this.addNotify({title:'Echec du téléchargement', type:'error'});
        });
  		  break;
  		case "t":
  			console.log('connecté en tant que technicien');
  		  break;
  		case "a":
        console.log('connecté en tant qu\'admin');

  			//Generation du tableau affichant les factures
		  	this.rapports = docsService.getRapports(null).then((data) =>  {
		      let dataJson = JSON.parse(data._body);
		      dataJson = _obj.transformUrlToFileName(dataJson);
          this.transformDate(dataJson);
		      _obj.rowsReports = dataJson;
          _obj.reportsFilter = [...dataJson];
		    }
		    ,(error)=>{
		      console.error(error);
		      // this.addNotify({title:'Echec du téléchargement', type:'error'});
		    });

		  	//Generation du tableau affichant les factures
		    this.factures = docsService.getFactures(null).then((data) =>  {
		      let dataJson = JSON.parse(data._body);
		      dataJson = _obj.transformUrlToFileName(dataJson);
          this.transformDate(dataJson);
		      _obj.rowsBills = dataJson;
          _obj.billsFilter = [...dataJson];
		    }
		    ,(error)=>{
		      console.error(error);
		      // this.addNotify({title:'Echec du téléchargement', type:'error'});
		    });    
  		  break;
  	}

    this.fetchFilterData((data) => {
      // cache our list
      console.log(data);
      this.tempFilter = [...data];

      // push our inital complete list
      this.rowsFilter = data;
    });

  }

  transformDate(json) {
    for(var i = 0 ; i < json.length ; i++) {
      var fullDate = new Date(json[i].created_at);
      let date = this.formatNumberWithZero(fullDate.getDate());
      let mounth = this.formatNumberWithZero(fullDate.getMonth()+1);
      let hours = this.formatNumberWithZero(fullDate.getHours());
      let minutes = this.formatNumberWithZero(fullDate.getMinutes());
      json[i].created_at = date+"/"+mounth+"/"+fullDate.getFullYear()+" - "+hours+":"+minutes;
    }
    return json;
  }
  formatNumberWithZero(number) {
    return (number < 10) ? "0"+number : number;
  }
  transformUrlToFileName(json) {
  	for(var i = 0 ; i < json.length ; i++) {
  		console.log(json);
      var filename = "<a href=assets/docs/"+json[i].type+'/'+json[i].url+" download> <b>"+json[i].url.split('/').pop()+"</b> </a>";
  		json[i].url= filename;
	  }
	return json;
  }

  fetchFilterData(cb) {
    const req = new XMLHttpRequest();
    req.open('GET', `assets/data/company.json`);

    req.onload = () => {
      cb(JSON.parse(req.response));
    };

    req.send();
  }

  updateFilter(event, rows) {
    const val = event.target.value.toLowerCase();
    switch (rows) {
      case "rowsReports":
        // filter our data and update the rows
        this.rowsReports = this.reportsFilter.filter(function(d) {
          return d.created_at.toLowerCase().indexOf(val) !== -1 || !val;
        });;
        break;
      case "rowsBills":
        this.rowsBills = this.billsFilter.filter(function(d) {
          return d.created_at.toLowerCase().indexOf(val) !== -1 || !val;
        });;
        break;
      case "rowsOthers":
        this.rowsOthers = this.othersFilter.filter(function(d) {
          return d.created_at.toLowerCase().indexOf(val) !== -1 || !val;
        });;
        break;
    }
    // Whenever the filter changes, always go back to the first page
    this.table.offset = 0;
  }

  onPage(event) {
    clearTimeout(this.timeout);
    this.timeout = setTimeout(() => {
      console.log('paged!', event);
    }, 100);
  }

  fetch(cb) {
    const req = new XMLHttpRequest();
    req.open('GET', `assets/data/100k.json`);

    req.onload = () => {
      const rows = JSON.parse(req.response);

      for(const row of rows) {
        row.height = Math.floor(Math.random() * 80) + 50;
      }

      cb(rows);
    };
    req.send();
  }

  getRowHeight(row) {
    return row.height;
  }

  downloadFile(filename) {
	  var export_path ="assets/data/rapports/" ;
	  return this.http
	    .get(export_path+filename+'.pdf', {
	      responseType: ResponseContentType.Blob
	      // search: // query string if have
	    })
	    .map(res => {
	      return {
	        filename: 'plots_'+filename+'.zip',
	        data: res.blob()
	      };
	    })
	    .subscribe(res => {
	        console.log('start download:',res);
	        var url = window.URL.createObjectURL(res.data);
	        var a = document.createElement('a');
	        document.body.appendChild(a);
	        a.setAttribute('style', 'display: none');
	        a.href = url;
	        a.download = res.filename;
	        a.click();
	        window.URL.revokeObjectURL(url);
	        a.remove(); // remove the element
	      }, error => {
	        console.log('download error:', JSON.stringify(error));
	      }, () => {
	        console.log('Completed file download.')
	      });
	}


  ngOnInit() {
  }
  setIdOfUsersUsigLocalSorage() {
    this._currentUserInfos = JSON.parse(localStorage.getItem('currentUserInfos'));


    switch (this._currentUserInfos.right) {
      case 1:
        this._idOfUsers.cooperative_id = 0;
        this._idOfUsers.technician_id = 0;
        this._idOfUsers.farmer_id = 0;
        this._idOfUsers.user_type = "a";
        break;
      case 2:
        this._idOfUsers.cooperative_id = this._currentUserInfos.cooperatives_id;
        this._idOfUsers.technician_id = 0;
        this._idOfUsers.farmer_id = 0;
        this._idOfUsers.user_type = "c";

        break;
      case 3:
        this._idOfUsers.cooperative_id = this._currentUserInfos.cooperatives_id;
        this._idOfUsers.technician_id = this._currentUserInfos.tchnicians_id;
        this._idOfUsers.farmer_id = 0;
        this._idOfUsers.user_type = "t";
        break;
      case 4:
        this._idOfUsers.cooperative_id = 0;//this._currentUserInfos.cooperatives_id; 
        this._idOfUsers.technician_id = 0;
        this._idOfUsers.farmer_id = this._currentUserInfos.farmer_id;
        this._idOfUsers.user_type = "f";

        break;
      // case '5':
      //         this._idOfUsers.cooperative_id = 0; 
      //         this._idOfUsers.adherent_id = 0 ;
      //         this._idOfUsers.technician_id = 0 ; 
      //         this._idOfUsers.farmer_id = 0 ;
      //         this._idOfUsers.user_type = "p"  ;

      //     break;
    }
  }

}
