import { Component, OnInit } from '@angular/core';
import { AuthenticationService } from '../../_services/index';
import { HttpService } from '../../http.service';
import { Http, ResponseContentType } from '@angular/http';
import { Router } from '@angular/router';
import { getDefaultLibFileName } from 'typescript';
import * as moment from 'moment';

import { NotificationsService } from "angular2-notifications";
@Component({
  selector: 'app-my-tours',
  templateUrl: './my-tours.component.html',
  styleUrls: ['./my-tours.component.css']
})
export class MyToursComponent implements OnInit {
  _idOfUsers = { "cooperative_id": 0, "technician_id": 0, "farmer_id": 0, "pilot_id": 0, "user_type": "t" }; //--------------!!!! // use to load a binding datas of a curent user or to filtering data 
  _currentUserInfos: any; //--------------!!!!
  _tourList = [];
  _tourListCopy = [];
  selecteTeam = [];
  selecteTeamCopy = [];
  selectePilot = [];
  selectePilotCopy = [];
  search = {
    selecteTeam: "null",
    selectePilot: "null",
    dateSince: null
  };
  
  //------------------------------------Notification------------------------------------
  options: any = {
    position: ["bottom", "right"],
  };
  position1: string = 'bottom';
  position2: string = 'right';
  timeOut: number = 6000;
  showProgressBar: boolean = true;
  pauseOnHover: boolean = true;
  lastOnBottom: boolean = true;
  clickToClose: boolean = true;
  maxLength: number = 0;
  maxStack: number = 8;
  preventDuplicates: boolean = false;
  preventLastDuplicates: boolean = false;
  theClass: string;
  rtl: boolean = false;
  animate: string = 'fromRight';
  icons: string;
  subType: string = 'success';

  title: string;
  msg: string;
  //------------------------------------Notification------------------------------------
  _tourIdx = 0;
  constructor(
    private httpService: HttpService,
    public authenticationService: AuthenticationService,
    private router: Router,
    private servicePNotify: NotificationsService,
    private http: Http,
  ) {
    if (this.authenticationService.isLoggedIn()) {
      this.setIdOfUsersUsigLocalSorage();
    } else {
      this.router.navigate(['/login']); //--------------!!!!
    }

  }

  ngOnInit() {
    this.getToursByUser(this._idOfUsers);
    if (this._currentUserInfos.right == 1) {
      this.getAllTeams();
      this.getAllPilot();
    }
  }
  getAllPilot() {
    this.httpService.httpPostPromise('getAllPilots', {})
      .then((data) => {
        console.log(data);
        this.selectePilot = data;
      }, (error) => {
        console.error(error);
      });
  }

  deleteTour(tour_id, tour_name){
    this.httpService.httpPostPromise('deleteTour', { "tour_id": tour_id })
    .then((data) => {
      this.addNotify({ title: 'Suppression d\'une tournée', msg: 'Suppression de la tournée : '+tour_name, type: 'error' });
      this.ngOnInit();
    }, (error) => {
      this.addNotify({ title: 'Echec suppression', msg: 'Echec de suppression de la tournée : '+tour_name, type: 'error' });
      console.error(error);
    });
  }

  exportTour(tour_id) {

    this.addNotify({ title: 'Exportation de la tournée ', msg: 'Chargement en cours, veuillez patienter...', type: 'success' });
    this.httpService.httpPostPromise('exportCSVTour', { tour_id: tour_id })
      .then((data) => {
        console.log(data);
        this.downloadTour(data.filename);
        this.addNotify({ title: 'Exportation de la tournée ', msg: 'Veuillez télécharger votre tournée.', type: 'success' });
      }, (error) => {
        console.error(error);
        this.addNotify({ title: 'Exportation de la tournée', msg: 'problème vient de serveur ! rafraichir la page :(', type: 'error' });
      });
  }
  downloadTour(path) {
    return this.http
      .get('assets/data/tournees_2018/' + path, {
        responseType: ResponseContentType.Blob
      })
      .map(res => {
        return {
          filename: path,
          data: res.blob()
        };
      })
      .subscribe(res => {
        console.log('start download:', res);
        var url = window.URL.createObjectURL(res.data);
        var a = document.createElement('a');
        document.body.appendChild(a);
        a.setAttribute('style', 'display: none');
        a.href = url;
        a.download = res.filename;
        a.click();
        window.URL.revokeObjectURL(url);
        a.remove(); // remove the element
      }, error => {
        console.log('download error:', JSON.stringify(error));
      }, () => {
        console.log('Completed file download.')
      });
  }
  getPilotByTeam() {
    // selectePilotCopy
  }
  searchTours(): void {
    console.log(this.search);
    var _obj = this;

    if (this.search.selectePilot === "null" && this.search.selecteTeam === "null" && this.search.dateSince == null) {
      this._tourList = this._tourListCopy;
    } else {
      var teamCondition = false;
      var pilotCondition = false;
      var dateSinceCondition = true;
      this._tourList = this._tourListCopy.filter(function (tag) {
        if (tag.team_id != null) {
          if (_obj.search.selecteTeam === "null") {
            teamCondition = true;
          } else {
            if (tag.team_id == _obj.search.selecteTeam) { teamCondition = true; }
            else {
              teamCondition = false;
            }
          }
        }
        if (tag.pilot_id != null) {
          if (_obj.search.selectePilot === "null") {
            pilotCondition = true;
          } else {
            var tabPilotIds = tag.pilot_id.substr(1, tag.pilot_id.length - 2).split(',');
            for (var i = 0; i < tabPilotIds.length; i++) {
              if (tabPilotIds[i] == _obj.search.selectePilot) { teamCondition = true; pilotCondition = true; break; }
            }
          }
        }
        if (tag.tour_date != null) {
          if (_obj.search.dateSince != null) {
            var month = _obj.search.dateSince.month;
            var day = _obj.search.dateSince.day;
            var year = _obj.search.dateSince.year;
            // console.log(year + "" + month + "" + day);
            if (day < 10) day = "0" + day;
            if (month < 10) month = "0" + month;
            // console.log(new Date(year + "/" + month + "/" + day));
            dateSinceCondition = _obj.filterByDate(new Date(tag.tour_date), new Date(year + "/" + month + "/" + day), "since");
            console.log(teamCondition, pilotCondition, dateSinceCondition);
          } else {
            dateSinceCondition = true;
          }
        }
        if (teamCondition && pilotCondition && dateSinceCondition) return true;

      });
      console.log(this._tourList);
    }
  }
  filterByDate(date1, date2, unity) {

    var now = moment(date1);
    var dateBefore = moment(date2);
    switch (unity) {
      case "since":
        console.log(now.diff(dateBefore, 'days') >= 0)
        console.log("now.diff(dateBefore, 'days') >=0")
        if (now.diff(dateBefore, 'days') >= 0) return true;
        else return false;
      case "today":
        console.log('days : ' + now.diff(dateBefore, 'days'));
        if (now.diff(dateBefore, 'days') != 0) return false;
        else return true;
      case "yesterday":
        if (now.diff(dateBefore, 'days') != 1) return false;
        else return true;
      case "this_week":
        if (now.diff(dateBefore, 'weeks') != 0) return false;
        else return true;
      case "this_month":
        if (now.diff(dateBefore, 'months') != 0) return false;
        else return true;
      case "this_year":
        if (now.diff(dateBefore, 'years') != 0) return false;
        else return true;
      default:
        return true;
    }
  }
  getAllTeams() {
    this.httpService.httpPostPromise('getTeams', {})
      .then((data) => {
        console.log(data);
        this.selecteTeam = data;
      }, (error) => {
        console.error(error);
      });
  }

  setIdOfUsersUsigLocalSorage() {
    this._currentUserInfos = JSON.parse(localStorage.getItem('currentUserInfos'));

    switch (this._currentUserInfos.right) {
      case 1:
        this._idOfUsers.cooperative_id = 0;
        this._idOfUsers.technician_id = 0;
        this._idOfUsers.farmer_id = 0;
        this._idOfUsers.pilot_id = 0;
        this._idOfUsers.user_type = "a";
        break;
      case 2:
        this._idOfUsers.cooperative_id = this._currentUserInfos.cooperatives_id;
        this._idOfUsers.technician_id = 0;
        this._idOfUsers.farmer_id = 0;
        this._idOfUsers.pilot_id = 0;
        this._idOfUsers.user_type = "c";

        break;
      case 3:
        this._idOfUsers.cooperative_id = this._currentUserInfos.cooperatives_id;
        this._idOfUsers.technician_id = this._currentUserInfos.tchnicians_id;
        this._idOfUsers.farmer_id = 0;
        this._idOfUsers.pilot_id = 0;
        this._idOfUsers.user_type = "t";
        break;
      case 4:
        this._idOfUsers.cooperative_id = 0;//this._currentUserInfos.cooperatives_id; 
        this._idOfUsers.technician_id = 0;
        this._idOfUsers.farmer_id = this._currentUserInfos.farmer_id;
        this._idOfUsers.pilot_id = 0;
        this._idOfUsers.user_type = "f";

        break;
      case 5:
        this._idOfUsers.cooperative_id = 0;
        this._idOfUsers.technician_id = 0;
        this._idOfUsers.farmer_id = 0;
        this._idOfUsers.pilot_id = this._currentUserInfos.pilot_id;
        this._idOfUsers.user_type = "p";

        break;
    }
  }
  getToursByUser(user_id) {
    console.log(user_id);
    this.httpService.httpPostPromise('getTours', user_id)
      .then((data) => {
        console.log(data);
        this._tourList = data;
        this._tourListCopy = data;
      }, (error) => {
        console.error(error);
      });
  }
  showTourOnMpa(tourId) {
  }
  getPlotNumbre(tabPlotString) {
    return tabPlotString.split(",").length - 2;
  }
  getTotalArea(area) {
    return parseFloat(area).toFixed(2);
  }
  getTotalDuration(duration) {
    var durationInMinut = parseFloat((duration % 1).toFixed(4));
    durationInMinut = 60 * durationInMinut;
    durationInMinut = durationInMinut - durationInMinut % 1;
    var durationInHour = parseFloat(duration) - parseFloat(duration) % 1;
    return durationInHour + ':' + durationInMinut;
  }
  getTotalDistance(dist) {
    return parseFloat(dist).toFixed(2) + ' Km';
  }
  addNotify(options) {
    //this.pauseOnHover = (options.indexOf("pauseOnHover") > -1) ? options.pauseOnHover : this.pauseOnHover;
    this.servicePNotify.remove();
    this.options = {
      position: [("position1" in options) ? options.position1 : this.position1, ("position2" in options) ? options.position2 : this.position2],
      maxStack: ("maxStack" in options) ? options.maxStack : this.maxStack,
      timeOut: options.timeOut ? options.timeOut : this.timeOut,
      showProgressBar: ('showProgressBar' in options) ? options.showProgressBar : this.showProgressBar,
      pauseOnHover: ('pauseOnHover' in options) ? options.pauseOnHover : this.pauseOnHover,
      lastOnBottom: ('lastOnBottom' in options) ? options.lastOnBottom : this.lastOnBottom,
      clickToClose: ('clickToClose' in options) ? options.clickToClose : this.clickToClose,
      maxLength: options.maxLength ? options.maxLength : this.maxLength,
      preventDuplicates: ('preventDuplicates' in options) ? options.preventDuplicates : this.preventDuplicates,
      preventLastDuplicates: ('preventLastDuplicates' in options) ? options.preventLastDuplicates : this.preventLastDuplicates,
      theClass: options.theClass ? options.theClass : this.theClass,
      rtl: ('rtl' in options) ? options.rtl : this.rtl,
      animate: options.animate ? options.animate : this.animate,
      icons: options.icons ? options.icons : this.icons
    }
    switch (options.type) {
      case 'success':
        this.servicePNotify.success(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg
        );
        break;
      case 'error':
        this.servicePNotify.error(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg
        );
        break;
      case 'alert':
        this.servicePNotify.error(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg
        );
        break;
      case 'warn':
        this.servicePNotify.error(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg
        );
        break;
      case 'info':
        this.servicePNotify.info(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg
        );
        break;
      case 'create':
        this.servicePNotify.create(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg,
          options.type ? options.type : this.subType
        );
        break;
      case 'html':
        this.servicePNotify.html(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg
        );
        break;
      default:
        this.servicePNotify.alert(
          options.title ? options.title : this.title,
          options.msg ? options.msg : this.msg
        );
        break;
    }
  }
}
