import * as  FeatureLayer from "luciad/view/feature/FeatureLayer";
import * as  FeatureModel from "luciad/model/feature/FeatureModel";
import * as  UrlStore from "luciad/model/store/UrlStore";
import * as  LocalFileStore from "samples/dataformats/LocalFileStore";
import * as  GeoJsonCodec from 'luciad/model/codec/GeoJsonCodec';
import * as  ShapeFactory from 'luciad/shape/ShapeFactory';
import * as  Feature from "luciad/model/feature/Feature";
import * as  ReferenceProvider from 'luciad/reference/ReferenceProvider';
import * as  Map from "luciad/view/Map";

import { HttpService } from '../../http.service';
import swal from 'sweetalert2';  

// _featureLayerPlotsDB : FeatureLayer;

export class PlotDataLoader {

  constructor(private _map: Map,
    private httpService: HttpService,
    private _featureLayerPlotsDB: FeatureLayer,
    private _featureLayerObstaclesDB: FeatureLayer,
    private _featureLayerAccessPointDB: FeatureLayer,
    private _plot_infos_geometry: any[]
  ) {

  }
  /**
   * Creates a layer for the given URL of File, assuming it is GeoJson content.
   *
   * You can style GeoJson data using a FeaturePainter.
   * See for example the <i>Vector Data<i> sample.
   *
   * Summary:
   * - Create a store to access the data, for example {@link luciad/model/store/UrlStore}
   * - Use {@link luciad/model/codec/GeoJsonCodec} in the store (this is the default)
   * - Create a {@link luciad/model/feature/FeatureModel} for the store
   * - Create a {@link luciad/view/feature/FeatureLayer}
   * - Create a {@link luciad/view/feature/FeaturePainter} to style the layer (optional)
   */
  createLayer(layerName, urlOrFile, painter) {
    //#snippet geojson
    var layer = new FeatureLayer(new FeatureModel(
      typeof urlOrFile === 'string' ?
        new UrlStore({ target: urlOrFile, codec: new GeoJsonCodec({ generateIDs: true }) }) :
        new LocalFileStore(urlOrFile, new GeoJsonCodec({ generateIDs: true }))
    ), {
        label: layerName + " (JSON)",
        selectable: true,
        painter: painter
      });
    //#endsnippet geojson
    return layer;
  }

  getAndPrintDataPlotFromDB(idOfCurentUser) {

    console.log(idOfCurentUser);
    var functionToCall;
    if (idOfCurentUser.user_type == "a") functionToCall = 'getPlotByAdmin';
    if (idOfCurentUser.user_type == "c") functionToCall = 'getPlotByCooperative';
    if (idOfCurentUser.user_type == "t") functionToCall = 'getPlotByTechnician';
    if (idOfCurentUser.user_type == "f") functionToCall = 'getPlotByFarmer';
    // if(idOfCurentUser.user_type=="p") functionToCall = 'getPlotByPilot';


    var promise = new Promise((resolve, reject) => {
      this.httpService.httpPostPromise(functionToCall, idOfCurentUser)
        .then((plot_infos_geometry) => {
          console.log(plot_infos_geometry);
          this.printPolygoneContour(plot_infos_geometry).then((plot_infos_geometry) => {
            // alert('1');
            resolve(plot_infos_geometry);
          });
        }, (error) => {
          console.log(error);
          reject('Error from db !');
        });
    });
    return promise;
  }

  getDataPlotFromDB(idOfCurentUser) {

    console.log(idOfCurentUser);
    var functionToCall;
    if (idOfCurentUser.user_type == "a") functionToCall = 'getPlotByAdmin';
    if (idOfCurentUser.user_type == "c") functionToCall = 'getPlotByCooperative';
    if (idOfCurentUser.user_type == "t") functionToCall = 'getPlotByTechnician';
    if (idOfCurentUser.user_type == "f") functionToCall = 'getPlotByFarmer';
    //if(idOfCurentUser.user_type=="p") functionToCall = 'getPlotByPilot';

    this.httpService.httpPostPromise(functionToCall, idOfCurentUser)
      .then((plot_infos_geometry) => {
        console.log(plot_infos_geometry);
        return plot_infos_geometry;
      }, (error) => {
        console.log(error);
      });
  }

  removePolygoneContour(plot_id) {
    for (var i = this._featureLayerPlotsDB.model.store._data.length - 1; i >= 0; i--) {
      if (this._featureLayerPlotsDB.model.store._data[i].properties.plot_id == plot_id) {
        console.log(this._featureLayerPlotsDB.model.store._data[i].id);
        this._featureLayerPlotsDB.model.remove(this._featureLayerPlotsDB.model.store._data[i].id);
      }
    }
    for (var i = this._featureLayerAccessPointDB.model.store._data.length - 1; i >= 0; i--) {
      if (this._featureLayerAccessPointDB.model.store._data[i].properties.plot_id == plot_id) {
        this._featureLayerAccessPointDB.model.remove(this._featureLayerAccessPointDB.model.store._data[i].id);
      }
    }
    console.log(this._plot_infos_geometry);
    console.log(this);
    for (var i = this._plot_infos_geometry.length - 1; i >= 0; i--) {

      if (this._plot_infos_geometry[i].plot_id == plot_id) {
        this._plot_infos_geometry.splice(i, 1);
      }
    }
  }

  removeAll() {
    for (var i = this._featureLayerPlotsDB.model.store._data.length - 1; i >= 0; i--) {
      console.log(this._featureLayerPlotsDB.model.store._data[i].id);
      this._featureLayerPlotsDB.model.remove(this._featureLayerPlotsDB.model.store._data[i].id);
    }
    for (var i = this._featureLayerAccessPointDB.model.store._data.length - 1; i >= 0; i--) {
      console.log(this._featureLayerAccessPointDB.model.store._data);
      this._featureLayerAccessPointDB.model.remove(this._featureLayerAccessPointDB.model.store._data[i].id);
    }
    for (var i = this._featureLayerObstaclesDB.model.store._data.length - 1; i >= 0; i--) {
      console.log(this._featureLayerObstaclesDB.model.store._data);
      this._featureLayerObstaclesDB.model.remove(this._featureLayerObstaclesDB.model.store._data[i].id);
    }

    this._plot_infos_geometry = [];
  }

  openSuccessSwal() {
    swal({
      title: 'Bon travail!',
      text: 'Le traitement à été bien sauvegardé, Votre commande sera traitée dans les plus brefs délais par l\'adminstrateur !',
      type: 'success'
    }).catch(swal.noop);
  }

  printPolygoneContour(plot_infos_geometry) {
    var ref = ReferenceProvider.getReference("EPSG:4326");

    for (var i = 0; i < plot_infos_geometry.length; i++) {
      var includedPlot = true;
      if (plot_infos_geometry[i].treatment.length == 0) {
        includedPlot = false;
        if (!includedPlot) continue;
      } else {
        includedPlot = false;
        for (var l = 0; l < plot_infos_geometry[i].treatment.length; l++) {
          // if(plot_infos_geometry[i].treatment[l].treatment_status=="commande" || plot_infos_geometry[i].treatment[l].treatment_status=="en-cours" ){
          if (plot_infos_geometry[i].treatment[l].treatment_status == "commande") {
            includedPlot = true;
            console.log(plot_infos_geometry[i]);
          }
        }
        if (!includedPlot) continue;
        console.log("plot_infos_geometry[i]" + "---continue---");
        console.log(plot_infos_geometry[i]);
        var poly = ShapeFactory.createPolygon(ref, []);
        var access_pointDB = JSON.parse(plot_infos_geometry[i].plot_access_point);
        var access_point = ShapeFactory.createPoint(ref, access_pointDB.coordinates);

        var polyDB = JSON.parse(plot_infos_geometry[i].plot_geometry).coordinates[0];
        for (var j = 0; j < polyDB.length; j++) {
          var marker = ShapeFactory.createPoint(ref, [polyDB[j][0], polyDB[j][1], polyDB[j][2]]);
          poly.insertPoint(j, marker);
        }

        var plot_properties = {
          farmer_id: plot_infos_geometry[i].farmer_id,
          farmer_first_name: plot_infos_geometry[i].farmer_first_name,
          farmer_name: plot_infos_geometry[i].farmer_name,
          farmer_phone: plot_infos_geometry[i].farmer_phone,

          technician_id: plot_infos_geometry[i].technician_id,
          technician_first_name: plot_infos_geometry[i].technician_first_name,
          technician_name: plot_infos_geometry[i].technician_name,

          plot_id: plot_infos_geometry[i].plot_id,
          plot_name: plot_infos_geometry[i].plot_name,
          plot_area: plot_infos_geometry[i].plot_area,
          plot_lat_access_point: access_point[0],
          plot_lon_access_point: access_point[1],
          plot_power_line: plot_infos_geometry[i].plot_power_line,
          plot_irrigation: plot_infos_geometry[i].plot_irrigation,
          plot_comment: plot_infos_geometry[i].plot_comment,
          plot_status: plot_infos_geometry[i].plot_status,
          plot_treatment: plot_infos_geometry[i].treatment,

          cooperative_id: plot_infos_geometry[i].cooperative_id,
          cooperative_name: plot_infos_geometry[i].cooperative_name,

          cooperative_adherent_id: plot_infos_geometry[i].cooperative_id,
          cooperative_adherent_name: plot_infos_geometry[i].cooperative_adherent,

        };
        var markerFeaturePlot = new Feature(poly);
        var markerFeatureAccessPoint = new Feature(access_point);
        markerFeaturePlot.properties = plot_properties;
        markerFeatureAccessPoint.properties = plot_properties;
        //Décommenter pour faire apparaitre le tableauDePoints
        var shape_id = this._featureLayerPlotsDB.model.add(markerFeaturePlot);
        var shape_id = this._featureLayerAccessPointDB.model.add(markerFeatureAccessPoint);


        // ----- Obstacles
        var obstaclesDB = JSON.parse(plot_infos_geometry[i].plot_obstacles);

        if (obstaclesDB) {
          obstaclesDB = obstaclesDB.coordinates;
          console.log(obstaclesDB);
          for (var j = 0; j < obstaclesDB.length; j++) {
            var obstacleDB = obstaclesDB[j];
            console.log(obstacleDB);
            var obstacle = ShapeFactory.createPolygon(ref, []);
            for (var k = 0; k < obstacleDB.length; k++) {
              var marker = ShapeFactory.createPoint(ref, [obstacleDB[k][0], obstacleDB[k][1], obstacleDB[k][2]]);
              obstacle.insertPoint(k, marker);
            }
            console.log(obstacle);

            var markerFeaturePlot = new Feature(obstacle);
            markerFeaturePlot.properties = plot_properties;
            //Décommenter pour faire apparaitre le tableauDePoints
            var shape_id = this._featureLayerObstaclesDB.model.add(markerFeaturePlot);
          }
        }

      }
    }
    if (this._featureLayerPlotsDB.model.store._data.length > 0) {
      this._map.mapNavigator.fit({ bounds: this._featureLayerPlotsDB.bounds, animate: false });
    }
    this._plot_infos_geometry = plot_infos_geometry;
    return Promise.resolve(this._plot_infos_geometry);
  }

}