import {Component,OnInit, ChangeDetectionStrategy, ViewChild, TemplateRef } from '@angular/core';
import {startOfDay,endOfDay,subDays,addDays,endOfMonth,isSameDay,isSameMonth,addHours} from 'date-fns';
import { Subject } from 'rxjs';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';
import {CalendarEvent,CalendarEventAction,CalendarEventTimesChangedEvent } from 'angular-calendar';
import { ToursService } from '../../_services/index';

const colors: any = {
  red: {
    primary: '#ad2121',
    secondary: '#FAE3E3'
  },
  blue: {
    primary: '#1e90ff',
    secondary: '#D1E8FF'
  },
  yellow: {
    primary: '#e3bc08',
    secondary: '#FDF1BA'
  }
};

@Component({
  selector: 'app-planning',
  templateUrl: './planning.component.html',
  styleUrls: ['./planning.component.css']
})

export class PlanningComponent implements OnInit {
	
	@ViewChild('modalContent') modalContent: TemplateRef<any>;
	view: string = 'month';
  	viewDate: Date = new Date();
  	calendar: string;
	activeDayIsOpen: boolean = false;
	refresh: Subject<any> = new Subject();

	modalData: {
		action: string;
		event: CalendarEvent;
  	};

  	actions: CalendarEventAction[] = [
	    {
	      label: '<i class="fa fa-fw fa-pencil"></i>',
	      onClick: ({ event }: { event: CalendarEvent }): void => {
	        this.handleEvent('Edited', event);
	      }
	    },
	    {
	      label: '<i class="fa fa-fw fa-times"></i>',
	      onClick: ({ event }: { event: CalendarEvent }): void => {
	        this.events = this.events.filter(iEvent => iEvent !== event);
	        this.handleEvent('Deleted', event);
	      }
	    }
	];

	events: CalendarEvent[] = [
	    {
	      start: subDays(startOfDay(new Date()), 1),
	      end: addDays(new Date(), 1),
	      title: 'A 3 day event',
	      color: colors.red,
	      actions: this.actions,
	      allDay: true,
	      resizable: {
	        beforeStart: true,
	        afterEnd: true
	      },
	      draggable: true
	    },
	    {
	      start: startOfDay(new Date()),
	      title: 'An event with no end date',
	      color: colors.yellow,
	      actions: this.actions
	    },
	    {
	      start: subDays(endOfMonth(new Date()), 3),
	      end: addDays(endOfMonth(new Date()), 3),
	      title: 'A long event that spans 2 months',
	      color: colors.blue,
	      allDay: true
	    },
	    {
	      start: addHours(startOfDay(new Date()), 2),
	      end: new Date(),
	      title: 'A draggable and resizable event',
	      color: colors.yellow,
	      actions: this.actions,
	      resizable: {
	        beforeStart: true,
	        afterEnd: true
	      },
	      draggable: true
	    }
	  ];

  	constructor(private modal: NgbModal, private toursService: ToursService) {
  		var res = this.toursService.getTours(null).then((data) =>  {
			let dataJson = JSON.parse(data._body);
			console.log(dataJson);
			this.formatEvents(dataJson);
			}
			,(error)=>{
			  console.error(error);
			  // this.addNotify({title:'Echec du téléchargement', type:'error'});
			});
  	}

  	ngOnInit() {
  	}

  	formatEvents(data) {
  		let res = [];
  		var _obj = this;
  		data.forEach(function(tour) {
  			let formatedData = {
				start: startOfDay(new Date(tour.date)),
		    	title: tour.name,
		    	id: tour.id,
		    	color: colors.blue,
		    	actions: _obj.actions,
		    	draggable: true,
		    	allDay: true
		    };
			res.push(formatedData);
		});
		console.log(res);
		this.events = res;
  	}

	dayClicked({ date, events }: { date: Date; events: CalendarEvent[] }): void {
	  if (isSameMonth(date, this.viewDate)) {
	    this.viewDate = date;
	    if (
	      (isSameDay(this.viewDate, date) && this.activeDayIsOpen === true) ||
	      events.length === 0
	    ) {
	    	// Uncomment to display modal info on a date button click 
	      this.activeDayIsOpen = false;
	    } else {
	      this.activeDayIsOpen = true;
	    }
	  }
	}

	eventTimesChanged({
	  event,
	  newStart,
	  newEnd
	}: CalendarEventTimesChangedEvent): void {
	  event.start = newStart;
	  event.end = newEnd;
	  console.log(event);
	  this.dragOrResizeEvent('Dropped or resized', event);
	  this.refresh.next();
	}

	handleEvent(action: string, event: CalendarEvent): void {
	  this.modalData = { event, action };
	  // Uncomment to display modal info on a date button click 
	  // this.modal.open(this.modalContent, { size: 'lg' });

	}

	dragOrResizeEvent(action: string, event: any): void {
	  event.date = event.start.getFullYear()+"-"+(event.start.getMonth()+1)+"-"+event.start.getDate();
	  this.toursService.setDateOfTour(event);
	  this.modalData = { event, action };
	  // this.modal.open(this.modalContent, { size: 'lg' });

	}

}