import * as LonLatGrid from 'luciad/view/grid/LonLatGrid';
import * as LonLatPointFormat  from 'luciad/shape/format/LonLatPointFormat';
import * as GridLayer from 'luciad/view/grid/GridLayer';
import * as ReferenceProvider from 'luciad/reference/ReferenceProvider';
import * as ShapeFactory from 'luciad/shape/ShapeFactory';
import * as FusionTileSetModel from 'luciad/model/tileset/FusionTileSetModel';
import * as RasterTileSetLayer from 'luciad/view/tileset/RasterTileSetLayer';

export class LayerFactory {
  static createLonLatGridLayer() {
    const settings = [
      {scale: 40000.0E-9, deltaLon: 1 / 60, deltaLat: 1 / 60},
      {scale: 20000.0E-9, deltaLon: 1 / 30, deltaLat: 1 / 30},
      {scale: 10000.0E-9, deltaLon: 1 / 10, deltaLat: 1 / 10},
      {scale: 5000.0E-9, deltaLon: 1 / 2, deltaLat: 1 / 2},
      {scale: 1000.0E-9, deltaLon: 1, deltaLat: 1},
      {scale: 200.0E-9, deltaLon: 5, deltaLat: 5},
      {scale: 20.0E-9, deltaLon: 10, deltaLat: 10},
      {scale: 9.0E-9, deltaLon: 20, deltaLat: 20},
      {scale: 5.0E-9, deltaLon: 30, deltaLat: 30},
      {scale: 0, deltaLon: 45, deltaLat: 45}

    ];
    const grid = new LonLatGrid(settings);

    grid.fallbackStyle = {
      labelFormat: new LonLatPointFormat({pattern: 'lat(+DM),lon(+DM)'}),
      originLabelFormat: new LonLatPointFormat({pattern: 'lat(+D),lon(+D)'}),
      originLineStyle: {
        color: 'rgba(230, 20, 20, 0.6)',
        width: 2
      },
      lineStyle: {
        color: 'rgba(210,210,210,0.6)',
        width: 1
      },
      originLabelStyle: {
        fill: 'rgba(210,210,210,0.8)',
        halo: 'rgba(230, 20, 20, 0.8)',
        haloWidth: '3px',
        font: '12px sans-serif'
      },
      labelStyle: {
        fill: 'rgb(220,220,220)',
        halo: 'rgb(102,102,102)',
        haloWidth: '3px',
        font: '12px sans-serif'
      }
    };

    const degreesOnlyFormat = new LonLatPointFormat({pattern: 'lat(+D),lon(+D)'});
    grid.setStyle(grid.scales.indexOf(0), {
      labelFormat: degreesOnlyFormat
    });
    grid.setStyle(grid.scales.indexOf(5.0E-9), {
      labelFormat: degreesOnlyFormat
    });
    grid.setStyle(grid.scales.indexOf(9.0E-9), {
      labelFormat: degreesOnlyFormat
    });
    grid.setStyle(grid.scales.indexOf(20.0E-9), {
      labelFormat: degreesOnlyFormat
    });
    grid.setStyle(grid.scales.indexOf(200.0E-9), {
      labelFormat: degreesOnlyFormat
    });
    return new GridLayer(grid, {label: 'Grid'});
  }

  static createBackgroundLayer() {
    const EPSG4326 = ReferenceProvider.getReference('EPSG:4326');
    const sampleServicesUrl = window.location.protocol + '//sampleservices.luciad.com/';
    const tileSetModelParams = {
      reference: EPSG4326,
      level0Columns: 4,
      level0Rows: 2,
      levelCount: 24,
      bounds: ShapeFactory.createBounds(EPSG4326, [-180, 360, -90, 180]),
      url: sampleServicesUrl + '/lts',
      coverageId: '4ceea49c-3e7c-4e2d-973d-c608fb2fb07e',
      tileWidth: 256,
      tileHeight: 256
    };
    const tileSetModel = new FusionTileSetModel(tileSetModelParams);
    return new RasterTileSetLayer(tileSetModel);
  }
}
