import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Response } from '@angular/http';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/operator/toPromise';
import { Observable } from "rxjs";
import {BackEndLink} from '../_config/back-end-link';
//import { AppConfig } from '../config/app.config';

@Injectable()
export class HttpService {

  private httpOptions ;
  private serverURL: string;
  currentUser ;
  private handleError(error: any) {
    if (error instanceof Response) {
      return Observable.throw(error.json()['error'] || 'backend server error');
    }
    return Observable.throw(error || 'backend server error');
  }

  constructor(private http: HttpClient,private backEndLink : BackEndLink) {
   // this.serverURL = AppConfig.endpoints.serverURL;
    this.currentUser = JSON.parse(localStorage.getItem('currentUser'));
    this.serverURL = this.backEndLink.getLinks().apiLaravel.serverURL; 
    this.httpOptions = {
	  headers : new HttpHeaders({
	    'Content-Type':  'application/json',
        'X-Auth-Token' :this.currentUser && this.currentUser.token ,
        'X-CSRF-Token': this.currentUser && this.currentUser.token , 
	    'Authorization': this.currentUser && this.currentUser.token   
	  })
    };
  }

  httpPost(sUrlFonctionAPI: string, data: any): Observable<any> {
    let url = this.serverURL + "/" + sUrlFonctionAPI;
    //const body = JSON.stringify(data);
    const body = data;
    return this.http.post(url, body, this.httpOptions)
      .map(response => {
        return response;
      })
      .catch(error => this.handleError(error));
  }

  httpPostPromise(sUrlFonctionAPI: string, data: any): Promise<any> {

    let url = this.serverURL + "/" + sUrlFonctionAPI;
    const body = data;
    return this.http.post(url, body, this.httpOptions)
      .map(response => {
        return response;
      }).toPromise()
      .catch(error => this.handleError(error));
  }


  httpGetPromise(sUrlFonctionAPI: string): Promise<any> {
    let url = this.serverURL + "/" + sUrlFonctionAPI;
    return this.http.get(url, this.httpOptions)
      .map(response => {
        return response;
      }).toPromise()
      .catch(error => this.handleError(error));
  }

    httpGet(sUrlFonctionAPI: string): Observable<any[]> {
    let url = this.serverURL + "/" + sUrlFonctionAPI;
    return this.http.get(url, this.httpOptions)
      .map(response => {
        return response;
      })
      .catch(error => this.handleError(error));
  }



  httpPut(sUrlFonctionAPI, data): Observable<any> {
    let url = this.serverURL + "/" + sUrlFonctionAPI;
    const body = JSON.stringify(data);
    console.log(body);
    return this.http.put(url, body, this.httpOptions)
      .map(response => {
        return response;
      })
      .catch(error => this.handleError(error));
  }


  httpDelete(sUrlFonctionAPI: string) {
    let url = this.serverURL + "/" + sUrlFonctionAPI;

    // Envoi de la requete
    return this.http.delete(url, this.httpOptions)
      .map(response => {
        return response;
      })
      .catch(error => this.handleError(error));
  }
}