import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { RouterModule } from '@angular/router';
import { NgModule,CUSTOM_ELEMENTS_SCHEMA,NO_ERRORS_SCHEMA } from '@angular/core';  
import { FormsModule } from '@angular/forms';
import { HttpModule } from '@angular/http';
import { HttpClientModule } from '@angular/common/http';
import { HttpService } from './http.service';  
import { AppRoutes } from './app.routing';
import { AppComponent } from './app.component';
import { AdminLayoutComponent } from './layouts/admin/admin-layout.component';
import { AuthLayoutComponent } from './layouts/auth/auth-layout.component';
import { SharedModule } from './shared/shared.module';
import { BreadcrumbsComponent } from './layouts/admin/breadcrumbs/breadcrumbs.component';
import { TitleComponent } from './layouts/admin/title/title.component';
import { ScrollModule} from './scroll/scroll.module';
import { LocationStrategy, PathLocationStrategy} from '@angular/common';
import { AdminService, TechnicianService, FarmerService, CooperativeService,InfosCurrentUserService,NotifyService, ProductService, DocumentsService, ToursService, MailService } from './_services/index';
import { HomeComponent } from './_components/home/home.component';
import { BackEndLink } from './_config/back-end-link';
import { LoginModule } from './_components/login/login.module';
import { FooterComponent } from './_components/footer/footer.component';
import { MyRiamapComponent } from './_components/my-riamap/my-riamap.component';
// import { RiaMapModule } from './_components/ria-map/ria-map.module';
import { RiaMapComponent } from './_components/ria-map/ria-map.component';
import { ListComponent } from './_components/orders/orderlist/list.component';
import { TechnicianFormComponent } from './_components/technician-form/technician-form.component';
import { FarmerFormComponent } from './_components/farmer-form/farmer-form.component';
import { CooperativeFormComponent } from './_components/cooperative-form/cooperative-form.component';
import { OrderComponent } from './_components/order/order.component';
import { FarmerListComponent } from './_components/farmer-list/farmer-list.component';
import { TechnicianListComponent } from './_components/technician-list/technician-list.component';
import { CooperativeListComponent } from './_components/cooperative-list/cooperative-list.component';
import { StockComponent } from './_components/stock/stock.component';
import { SmsComponent } from './_components/sms/sms.component';
// import { DeviceDetectorModule } from 'ngx-device-detector';
import { DeviceDetector } from './_class/DeviceDetector'; 
import { NetworkConnectionDetector } from './_class/NetworkConnectionDetector';
import { UserTypeConnectionDetector } from './_class/UserTypeConnectionDetector';
import { TechnicianUpdateComponent } from './_components/technician-update/technician-update.component';
import {LazyForModule} from 'angular-lazy-for';
import { AmChartsModule } from '@amcharts/amcharts3-angular';
import { TreatmentlistComponent } from './_components/orders/treatmentlist/treatmentlist.component';
// import {LocalStorageDefinition } from './_class/LocalStorageDefinition'
import { DocumentsComponent } from './_components/documents/documents.component'; 
import { UploadFilesComponent } from './_components/upload-files/upload-files.component'; 

import { PlanningComponent } from './_components/planning/planning.component'; 
import { CalendarModule } from 'angular-calendar';
import { SvgIconComponent } from './_components/svg-icon/svg-icon.component';
import { OrderV2Component } from './_components/order-v2/order-v2.component';
import { TourListComponent } from './_components/tour-list/tour-list.component';
import { NewTourComponent } from './_components/new-tour/new-tour.component';
import { FollowPlotStatesComponent } from './_components/follow-plot-states/follow-plot-states.component';
import { MyToursComponent } from './_components/my-tours/my-tours.component';

@NgModule({
  declarations: [
    AppComponent,
    AdminLayoutComponent,
    AuthLayoutComponent,
    BreadcrumbsComponent,
    TitleComponent,
    FooterComponent,
    HomeComponent,
    MyRiamapComponent,
    TechnicianFormComponent,
    FarmerFormComponent,
    CooperativeFormComponent,
    OrderComponent,
    FarmerListComponent,
    TechnicianListComponent,
    CooperativeListComponent,
    StockComponent,
    SmsComponent,
    TechnicianUpdateComponent,
    RiaMapComponent,
    ListComponent,
    TreatmentlistComponent,
    DocumentsComponent,
    UploadFilesComponent,
    PlanningComponent,
    SvgIconComponent,
    OrderV2Component,
    TourListComponent,
    NewTourComponent,
    FollowPlotStatesComponent,
    MyToursComponent
    ],
  imports: [
    LoginModule,
    BrowserModule,
    BrowserAnimationsModule,
    SharedModule,
    RouterModule.forRoot(AppRoutes),
    FormsModule,
    HttpModule,
    HttpClientModule,
    ScrollModule,/*,
    DeviceDetectorModule.forRoot()*/
    AmChartsModule,
    LazyForModule,
    // RiaMapModule
    CalendarModule.forRoot({ })
  ],
  exports: [ScrollModule],
  providers: [BackEndLink,HttpService, AdminService, TechnicianService, FarmerService, CooperativeService,InfosCurrentUserService,NotifyService,ToursService, MailService,
  ProductService, DeviceDetector, NetworkConnectionDetector, UserTypeConnectionDetector, DocumentsService,
      { provide: LocationStrategy, useClass: PathLocationStrategy }
  ],
  // schemas: [ CUSTOM_ELEMENTS_SCHEMA],
  bootstrap: [AppComponent]
})
export class AppModule {}
