import {Component, OnInit, ViewEncapsulation, ElementRef, OnDestroy} from '@angular/core';

import {IOption} from "ng-select";
import {SelectOptionService} from "../../../shared/elements/select-option.service";
import {Subscription} from "rxjs/Subscription";
import {Observable} from "rxjs";
import {Http, Response} from "@angular/http";

@Component({
  selector: 'app-select',
  templateUrl: './select.component.html',
  styleUrls: ['./select.component.css'],
  encapsulation: ViewEncapsulation.None
})
export class SelectComponent implements OnInit, OnDestroy {

  simpleOption: Array<IOption> = this.selectOptionService.getCharacters();
  selectedOption: string = '3';
  isDisabled: boolean = true;
  characters: Array<IOption>;
  selectedCharacter: string = '3';
  timeLeft: number = 5;

  countries: Array<IOption> = this.selectOptionService.getCountries();
  selectedCountry: string = 'IN';
  selectedCountries: Array<string> = ['IN', 'BE', 'LU', 'NL'];

  private dataSub: Subscription = null;

  autocompleteItems = ['Alabama', 'Wyoming', 'Henry Die', 'John Doe'];
  autocompleteItemsAsObjects = [
    {value: 'Alabama', id: 0},
    {value: 'Wyoming', id: 1},
    {value: 'Coming', id: 2},
    {value: 'Josephin Doe', id:3},
    {value: 'Henry Die', id:4},
    {value: 'Lary Doe', id:5},
    {value: 'Alice', id:6},
    {value: 'Alia', id:7},
    {value: 'Suzen', id:8},
    {value: 'Michael Scofield', id:9},
    {value: 'Irina Shayk', id:10},
    {value: 'Sara Tancredi', id:11},
    {value: 'Daizy Mendize', id:12},
    {value: 'Loren Scofield', id:13},
    {value: 'Shayk', id:14},
    {value: 'Sara', id:15},
    {value: 'Doe', id:16},
    {value: 'Lary', id:17},
    {value: 'Roni Sommerfield', id:18},
    {value: 'Mickey Amavisca', id:19},
    {value: 'Dorethea Hennigan', id:20},
    {value: 'Marisha Haughey', id:21},
    {value: 'Justin Czajkowski', id:22},
    {value: 'Reyes Hodges', id:23},
    {value: 'Vicky Hadley', id:24},
    {value: 'Lezlie Baumert', id:25},
    {value: 'Otha Vanorden', id:26},
    {value: 'Glayds Inabinet', id:27},
    {value: 'Hang Owsley', id:28},
    {value: 'Carlotta Buttner', id:29},
    {value: 'Randa Vanloan', id:30},
    {value: 'Elana Fulk', id:31},
    {value: 'Amos Spearman', id:32},
    {value: 'Samon', id:33},
    {value: 'John Doe', id: 34}
  ];
  constructor(public selectOptionService: SelectOptionService, public http:Http, public elementRef: ElementRef) { }

  ngOnInit() {
    this.runTimer();
    this.dataSub = this.selectOptionService.loadCharacters().subscribe((options) => {
      this.characters = options;
    });
  }

  ngOnDestroy() {
    if (this.dataSub !== null) { this.dataSub.unsubscribe(); }
  }

  runTimer() {
    let timer = setInterval(() => {
      this.timeLeft -= 1;
      if (this.timeLeft === 0) {
        clearInterval(timer);
      }
    }, 1000);
  }

  public requestAutocompleteItems = (text: string): Observable<Response> => {
    const url = `https://api.github.com/search/repositories?q=${text}`;
    return this.http
        .get(url)
        .map(data => data.json().items.map(item => item.full_name));
  };

}